from setuptools import setup

setup(name='udacity_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['udacity_distributions'],
      zip_safe=False,
      author='Ashish Subedi',
      author_email='subediashish35@gmail.com'
     )
